@@ -9,7 +9,6 @@ from kabaret.flow_entities.store import EntityStore
 from libreflow import _version as libreflow_version
 from libreflow.rouge import _version as project_version
 
-from libreflow.utils.kabaret.flow_entities.entities import GlobalEntityCollection
 from libreflow.baseflow import (
     ProjectSettings as BaseProjectSettings,
     MultisiteConfig,
@@ -18,8 +17,9 @@ from libreflow.baseflow import (
     LoginPage,
     LogOut
 )
+from libreflow.baseflow.film import FilmCollection
+from libreflow.baseflow.task_manager import TaskManager
 from libreflow.baseflow.users import Users, UserProfile, UserEnvironment
-from libreflow.baseflow.file import TrackedFile, TrackedFolder
 from libreflow.baseflow.site import GotoCurrentSiteQueue
 from libreflow.baseflow.runners import (
     Blender,
@@ -28,40 +28,27 @@ from libreflow.baseflow.runners import (
     DefaultRunners
 )
 
-from .film import Films
+from .entity_manager import EntityManager
+from .film import Film
+from .shot import Sequence, Shot
+from .task import Task
 from .users import User
 from .file import (
+    TrackedFile,
+    TrackedFolder,
     Revision,
     TrackedFolderRevision,
-    SyncStatutes,
-    Revisions,
-    TrackedFolderRevisions,
-    HistorySyncStatutes,
 )
 
 
 class ProjectSettings(BaseProjectSettings):
 
+    task_manager      = flow.Child(TaskManager)
+
     libreflow_version = flow.Param('0.0.0').ui(editable=False)
     project_version   = flow.Param('0.0.0').ui(editable=False)
 
 
-class EntityManager(flow.Object):
-    '''
-    This class manages the entity store and all global
-    entity collections of this project.
-    '''
-
-    store = flow.Child(EntityStore)
-
-    films         = flow.Child(GlobalEntityCollection)
-    sequences     = flow.Child(GlobalEntityCollection)
-    shots         = flow.Child(GlobalEntityCollection)
-    files         = flow.Child(GlobalEntityCollection)
-    revisions     = flow.Child(GlobalEntityCollection)
-    sync_statutes = flow.Child(GlobalEntityCollection)
-
-
 class Synchronization(flow.Object):
 
     ICON = ('icons.libreflow', 'sync')
@@ -108,23 +95,29 @@ class Project(flow.Object):
     log_out_action  = flow.Child(LogOut).ui(label='Log out')
     user            = flow.Child(UserProfile)
     synchronization = flow.Child(Synchronization)
-    films           = flow.Child(Films).ui(expanded=True)
+    films           = flow.Child(FilmCollection).ui(expanded=True)
     admin           = flow.Child(Admin)
 
     _RUNNERS_FACTORY = None
 
     @classmethod
     def _injection_provider(cls, slot_name, default_type):
-        if slot_name == 'libreflow.baseflow.file.SyncStatutes':
-            return SyncStatutes
+        if slot_name == 'libreflow.baseflow.film.Film':
+            return Film
+        elif slot_name == 'libreflow.baseflow.shot.Sequence':
+            return Sequence
+        elif slot_name == 'libreflow.baseflow.shot.Shot':
+            return Shot
+        elif slot_name == 'libreflow.baseflow.file.ManagedTask':
+            return Task
+        elif slot_name == 'libreflow.baseflow.file.TrackedFile':
+            return TrackedFile
+        elif slot_name == 'libreflow.baseflow.file.TrackedFolder':
+            return TrackedFolder
         elif slot_name == 'libreflow.baseflow.file.Revision':
             return Revision
-        elif slot_name == 'libreflow.baseflow.file.Revisions':
-            return Revisions
-        elif slot_name == 'libreflow.baseflow.file.TrackedFolderRevisions':
-            return TrackedFolderRevisions
-        elif slot_name == 'libreflow.baseflow.file.HistorySyncStatutes':
-            return HistorySyncStatutes
+        elif slot_name == 'libreflow.baseflow.file.TrackedFolderRevision':
+            return TrackedFolderRevision
         elif slot_name == 'libreflow.baseflow.users.User':
             return User
     
@@ -219,9 +212,15 @@ class Project(flow.Object):
     def get_entity_store(self):
         return self.admin.entity_manager.store
     
+    def get_task_manager(self):
+        return self.admin.project_settings.task_manager
+    
     def get_sync_manager(self):
         return self.synchronization.synchronize_files
     
+    def get_action_value_store(self):
+        return self.get_entity_manager().action_value_store
+    
     def kitsu_config(self):
         return self.admin.kitsu
     
